@@ -15,11 +15,12 @@
  */
 
 #include "coverproxy.h"
-#include "covermanager.h"
 
-#include <kdebug.h>
 #include <kio/job.h>
 
+#include "covermanager.h"
+#include "juk_debug.h"
+
 CoverProxy::CoverProxy(QObject *parent) :
     QObject(parent)
 {
@@ -28,12 +29,10 @@ CoverProxy::CoverProxy(QObject *parent) :
 void CoverProxy::handleResult(KJob *job)
 {
     if(job->error()) {
-        kError() << "Cover download job failed with the following error:" << job->errorString();
+        qCCritical(JUK_LOG) << "Cover download job failed with the following error:" << job->errorString();
         CoverManager::jobComplete(job, false);
     }
     else {
         CoverManager::jobComplete(job, true);
     }
 }
-
-#include "coverproxy.moc"
